@@ -243,6 +243,22 @@ var encoderDecoderOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::coolData:\n    a: apple\n",
 		},
 	},
+	{
+		description: "empty base64 decode",
+		skipDoc:     true,
+		expression:  `"" | @base64d`,
+		expected: []string{
+			"D0, P[], (!!str)::\n",
+		},
+	},
+	{
+		description: "empty xml decode",
+		skipDoc:     true,
+		expression:  `"" | @xmld`,
+		expected: []string{
+			"D0, P[], (!!null)::\n",
+		},
+	},
 }
 
 func TestEncoderDecoderOperatorScenarios(t *testing.T) {
